Motor
=====

.. autoclass:: physics.models.motor.BasicMotor
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.motor.BaseMotor
   :members:
   :undoc-members:
   :show-inheritance: